@@ -7,13 +7,15 @@ GCP_PROJECT = os.environ["GCP_PROJECT"]
 FUNCTION_REGION = os.environ["FUNCTION_REGION"]
 
 
-class ServiceError(Exception):
-    def __init__(self, status_code, message):
-        if status_code >= 500:
-            logging.error(message)
-        else:
-            logging.warning(message)
-        super().__init__(message)
+class ServiceResponse:
+    def __init__(self, response: requests.Response):
+        try:
+            self.data = response.json()
+        except ValueError:
+            self.data = None
+        self.raw_content = response.content
+        self.status_code = response.status_code
+        self.raise_for_status = response.raise_for_status
 
 
 def get_auth_header(audience):
@@ -29,13 +31,9 @@ def get_auth_header(audience):
 
 
 def call(name, **kwargs):
-    domain = f"https://{FUNCTION_REGION}-{GCP_PROJECT}.cloudfunctions.net"
-    url = urljoin(domain, name)
-    logging.info("CALL: %s", name)
-    logging.info(kwargs)
+    url = f"https://{FUNCTION_REGION}-{GCP_PROJECT}.cloudfunctions.net/{name}"
+    logging.info("CALL: %s %s", name, kwargs)
     r = requests.post(url, headers=get_auth_header(url), json=kwargs)
-    resp = r.json()
-    logging.info("RESPONSE: %s", name)
-    logging.info(resp)
-    r.raise_for_status()
-    return resp
+    service_resp = ServiceResponse(r)
+    logging.info("RESPONSE: %s %s", service_resp.status_code, service_resp.data)
+    return service_resp
