@@ -18,8 +18,12 @@ def _configuration(wid, cid=None):
     return _workspace(wid).collection(Types.CONFIGURATIONS).document(cid)
 
 
-def add_configuration(wid, name):
-    ref = _configuration(wid)
+def generate_id():
+    return client.collection("").document().id
+
+
+def add_configuration(wid, name, cid=None):
+    ref = _configuration(wid, cid)
     ref.set({"name": name})
     return ref.id
 
@@ -31,4 +35,5 @@ def get_configuration_by_name(wid, name):
         .where("name", "==", name)
         .limit(1)
     )
-    return next(query.stream(), None)
+    result = next(query.stream(), None)
+    return result.to_dict() if result else None
