@@ -40,6 +40,12 @@ def create_merge(repo, base, head, message):
     )
 
 
+def get_contents(repo, filename, branch):
+    return _github(
+        root="repos", path=f"{repo}/contents/{filename}?ref={branch}", method="GET",
+    )
+
+
 def update_contents(repo, filename, content, branch, message):
     return _github(
         root="repos",
